LKML Archive on lore.kernel.org
help / color / mirror / Atom feed
From: Ingo Molnar <mingo@elte.hu>
To: Linus Torvalds <torvalds@linux-foundation.org>
Cc: linux-kernel@vger.kernel.org, Thomas Gleixner <tglx@linutronix.de>
Subject: [GIT PULL] irq fix
Date: Mon, 10 Aug 2009 20:15:41 +0200 [thread overview]
Message-ID: <20090810181541.GA31253@elte.hu> (raw)
Linus,
Please pull the latest irq-fixes-for-linus git tree from:
git://git.kernel.org/pub/scm/linux/kernel/git/tip/linux-2.6-tip.git irq-fixes-for-linus
Thanks,
Ingo
------------------>
Yinghai Lu (1):
x86/irq: Fix move_irq_desc() for nodes without ram
kernel/irq/numa_migrate.c | 4 ++--
1 files changed, 2 insertions(+), 2 deletions(-)
diff --git a/kernel/irq/numa_migrate.c b/kernel/irq/numa_migrate.c
index 2f69bee..3fd3019 100644
--- a/kernel/irq/numa_migrate.c
+++ b/kernel/irq/numa_migrate.c
@@ -107,8 +107,8 @@ out_unlock:
struct irq_desc *move_irq_desc(struct irq_desc *desc, int node)
{
- /* those all static, do move them */
- if (desc->irq < NR_IRQS_LEGACY)
+ /* those static or target node is -1, do not move them */
+ if (desc->irq < NR_IRQS_LEGACY || node == -1)
return desc;
if (desc->node != node)
next reply other threads:[~2009-08-10 18:15 UTC|newest]
Thread overview: 26+ messages / expand[flat|nested] mbox.gz Atom feed top
2009-08-10 18:15 Ingo Molnar [this message]
2009-11-10 17:50 Ingo Molnar
2010-12-08 8:05 Ingo Molnar
2011-02-03 17:14 Ingo Molnar
2011-04-07 17:46 Ingo Molnar
2011-04-22 13:33 Ingo Molnar
2011-05-03 11:48 Ingo Molnar
2011-06-13 9:51 Ingo Molnar
2011-12-05 19:03 Ingo Molnar
2012-08-03 16:37 Ingo Molnar
2013-10-04 7:51 Ingo Molnar
2014-04-16 12:59 Ingo Molnar
2015-05-15 7:13 Ingo Molnar
2016-01-08 12:42 Ingo Molnar
2016-08-12 19:22 [GIT PULL] IRQ fix Ingo Molnar
2016-10-28 8:33 [GIT PULL] irq fix Ingo Molnar
2016-11-14 7:59 [GIT PULL] IRQ fix Ingo Molnar
2016-12-23 22:46 Ingo Molnar
2017-03-07 20:24 Ingo Molnar
2017-11-05 14:37 Ingo Molnar
2019-09-12 8:35 Ingo Molnar
2019-09-12 10:15 ` pr-tracker-bot
2020-01-18 17:19 Ingo Molnar
2020-01-18 21:05 ` pr-tracker-bot
2021-05-15 7:44 Ingo Molnar
2021-05-15 17:55 ` pr-tracker-bot
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20090810181541.GA31253@elte.hu \
--to=mingo@elte.hu \
--cc=linux-kernel@vger.kernel.org \
--cc=tglx@linutronix.de \
--cc=torvalds@linux-foundation.org \
--subject='Re: [GIT PULL] irq fix' \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for NNTP newsgroup(s).